<html>
<head>
<title>img0ch - GAvbg̃LoX</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="Robot" content="NOINDEX,NOFOLLOW">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/fastserialize.js"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");

/*
 * pallet from sugadokoro
 * (http://sugachan.dip.jp/oekaki/imgboard.cgi)
 */
var ColorPallet = new Array();
ColorPallet[1] = "%23FFDFDF%0A%23FF0000%0A%23FFBFBF%0A%23DF0000%0A%23FF9F9F%0A%23BF0000%0A%23FF7F7F%0A%239F0000%0A%23FF5F5F%0A%237F0000%0A%23FF3F3F%0A%235F0000%0A%23FF1F1F%0A%233F0000%0A";
ColorPallet[2] = "%23FFE7DF%0A%23FF3F00%0A%23FFCFBF%0A%23DF3700%0A%23FFB79F%0A%23BF2F00%0A%23FF9F7F%0A%239F2700%0A%23FF875F%0A%237F1F00%0A%23FF6F3F%0A%235F1700%0A%23FF571F%0A%233F0F00%0A";
ColorPallet[3] = "%23FFEFDF%0A%23FF7F00%0A%23FFDFBF%0A%23DF6F00%0A%23FFCF9F%0A%23BF5F00%0A%23FFBF7F%0A%239F4F00%0A%23FFAF5F%0A%237F3F00%0A%23FF9F3F%0A%235F2F00%0A%23FF8F1F%0A%233F1F00%0A";
ColorPallet[4] = "%23FFF7DF%0A%23FFBF00%0A%23FFEFBF%0A%23DFA700%0A%23FFE79F%0A%23BF8F00%0A%23FFDF7F%0A%239F7700%0A%23FFD75F%0A%237F5F00%0A%23FFCF3F%0A%235F4700%0A%23FFC71F%0A%233F2F00%0A";
ColorPallet[5] = "%23FFFFDF%0A%23FFFF00%0A%23FFFFBF%0A%23DFDF00%0A%23FFFF9F%0A%23BFBF00%0A%23FFFF7F%0A%239F9F00%0A%23FFFF5F%0A%237F7F00%0A%23FFFF3F%0A%235F5F00%0A%23FFFF1F%0A%233F3F00%0A";
ColorPallet[6] = "%23F7FFDF%0A%23BFFF00%0A%23EFFFBF%0A%23A7DF00%0A%23E7FF9F%0A%238FBF00%0A%23DFFF7F%0A%23779F00%0A%23D7FF5F%0A%235F7F00%0A%23CFFF3F%0A%23475F00%0A%23C7FF1F%0A%232F3F00%0A";
ColorPallet[7] = "%23EFFFDF%0A%237FFF00%0A%23DFFFBF%0A%236FDF00%0A%23CFFF9F%0A%235FBF00%0A%23BFFF7F%0A%234F9F00%0A%23AFFF5F%0A%233F7F00%0A%239FFF3F%0A%232F5F00%0A%238FFF1F%0A%231F3F00%0A";
ColorPallet[8] = "%23E7FFDF%0A%233FFF00%0A%23CFFFBF%0A%2337DF00%0A%23B7FF9F%0A%233FBF00%0A%239FFF7F%0A%23279F00%0A%2387FF5F%0A%231F7F00%0A%236FFF3F%0A%23175F00%0A%2357FF1F%0A%230F3F00%0A";
ColorPallet[9] = "%23DFFFDF%0A%2300FF00%0A%23BFFFBF%0A%2300DF00%0A%239FFF9F%0A%2300BF00%0A%237FFF7F%0A%23009F00%0A%235FFF5F%0A%23007F00%0A%233FFF3F%0A%23005F00%0A%231FFF1F%0A%23003F00%0A";
ColorPallet[10] = "%23DFFFE7%0A%2300FF3F%0A%23BFFFCF%0A%2300DF37%0A%239FFFB7%0A%2300BF3F%0A%237FFF9F%0A%23009F27%0A%235FFF87%0A%23007F1F%0A%233FFF6F%0A%23005F17%0A%231FFF57%0A%23003F0F%0A";
ColorPallet[11] = "%23DFFFEF%0A%2300FF7F%0A%23BFFFDF%0A%2300DF6F%0A%239FFFCF%0A%2300BF5F%0A%237FFFBF%0A%23009F4F%0A%235FFFAF%0A%23007F3F%0A%233FFF9F%0A%23005F2F%0A%231FFF8F%0A%23003F1F%0A";
ColorPallet[12] = "%23DFFFF7%0A%2300FFBF%0A%23BFFFEF%0A%2300DFA7%0A%239FFFE7%0A%2300BF8F%0A%237FFFDF%0A%23009F77%0A%235FFFD7%0A%23007F5F%0A%233FFFCF%0A%23005F47%0A%231FFFC7%0A%23003F2F%0A";
ColorPallet[13] = "%23DFFFFF%0A%2300FFFF%0A%23BFFFFF%0A%2300DFDF%0A%239FFFFF%0A%2300BFBF%0A%237FFFFF%0A%23009F9F%0A%235FFFFF%0A%23007F7F%0A%233FFFFF%0A%23005F5F%0A%231FFFFF%0A%23003F3F%0A";
ColorPallet[14] = "%23DFF7FF%0A%2300BFFF%0A%23BFEFFF%0A%2300A7DF%0A%239FE7FF%0A%23008FBF%0A%237FDFFF%0A%2300779F%0A%235FD7FF%0A%23005F7F%0A%233FCFFF%0A%2300475F%0A%231FC7FF%0A%23002F3F%0A";
ColorPallet[15] = "%23DFEFFF%0A%23007FFF%0A%23BFDFFF%0A%23006FDF%0A%239FCFFF%0A%23005FBF%0A%237FBFFF%0A%23004F9F%0A%235FAFFF%0A%23003F7F%0A%233F9FFF%0A%23002F5F%0A%231F8FFF%0A%23001F3F%0A";
ColorPallet[16] = "%23DFE7FF%0A%23003FFF%0A%23BFCFFF%0A%230037DF%0A%239FB7FF%0A%23003FBF%0A%237F9FFF%0A%2300279F%0A%235F87FF%0A%23001F7F%0A%233F6FFF%0A%2300175F%0A%231F57FF%0A%23000F3F%0A";
ColorPallet[17] = "%23DFDFFF%0A%230000FF%0A%23BFBFFF%0A%230000DF%0A%239F9FFF%0A%230000BF%0A%237F7FFF%0A%2300009F%0A%235F5FFF%0A%2300007F%0A%233F3FFF%0A%2300005F%0A%231F1FFF%0A%2300003F%0A";
ColorPallet[18] = "%23E7DFFF%0A%233F00FF%0A%23CFBFFF%0A%233700DF%0A%23B79FFF%0A%233F00BF%0A%239F7FFF%0A%2327009F%0A%23875FFF%0A%231F007F%0A%236F3FFF%0A%2317005F%0A%23571FFF%0A%230F003F%0A";
ColorPallet[19] = "%23EFDFFF%0A%237F00FF%0A%23DFBFFF%0A%236F00DF%0A%23CF9FFF%0A%235F00BF%0A%23BF7FFF%0A%234F009F%0A%23AF5FFF%0A%233F007F%0A%239F3FFF%0A%232F005F%0A%238F1FFF%0A%231F003F%0A";
ColorPallet[20] = "%23F7DFFF%0A%23BF00FF%0A%23EFBFFF%0A%23A700DF%0A%23E79FFF%0A%238F00BF%0A%23DF7FFF%0A%2377009F%0A%23D75FFF%0A%235F007F%0A%23CF3FFF%0A%2347005F%0A%23C71FFF%0A%232F003F%0A";
ColorPallet[21] = "%23FFDFFF%0A%23FF00FF%0A%23FFBFFF%0A%23DF00DF%0A%23FF9FFF%0A%23BF00BF%0A%23FF7FFF%0A%239F009F%0A%23FF5FFF%0A%237F007F%0A%23FF3FFF%0A%235F005F%0A%23FF1FFF%0A%233F003F%0A";
ColorPallet[22] = "%23FFDFF7%0A%23FF00BF%0A%23FFBFEF%0A%23DF00A7%0A%23FF9FE7%0A%23BF008F%0A%23FF7FDF%0A%239F0077%0A%23FF5FD7%0A%237F005F%0A%23FF3FCF%0A%235F0047%0A%23FF1FC7%0A%233F002F%0A";
ColorPallet[23] = "%23FFDFEF%0A%23FF007F%0A%23FFBFDF%0A%23DF006F%0A%23FF9FCF%0A%23BF005F%0A%23FF7FBF%0A%239F004F%0A%23FF5FAF%0A%237F003F%0A%23FF3F9F%0A%235F002F%0A%23FF1F8F%0A%233F001F%0A";
ColorPallet[24] = "%23FFDFE7%0A%23FF003F%0A%23FFBFCF%0A%23DF0037%0A%23FF9FB7%0A%23BF003F%0A%23FF7F9F%0A%239F0027%0A%23FF5F87%0A%237F001F%0A%23FF3F6F%0A%235F0017%0A%23FF1F57%0A%233F000F%0A";
ColorPallet[25] = "%23F0F0F0%0A%23808080%0A%23E0E0E0%0A%23707070%0A%23D0D0D0%0A%23606060%0A%23C0C0C0%0A%23505050%0A%23B0B0B0%0A%23404040%0A%23A0A0A0%0A%23303030%0A%23909090%0A%23202020%0A";
ColorPallet[26] = "%23FFF2E1%0A%23FFEDE1%0A%23FFEED7%0A%23FFE7D7%0A%23FFE9CD%0A%23FFE1CD%0A%23FFE5C3%0A%23FFDBC3%0A%23FFE1B9%0A%23FFD5B9%0A%23FFDCAF%0A%23FFCFAF%0A%23FFD8A5%0A%23FFC9A5%0A";
ColorPallet[27] = "%23ECDBCC%0A%23916137%0A%23E2C6AE%0A%23744E2C%0A%23D7B291%0A%23573A21%0A%23CD9D73%0A%233A2716%0A%23C18957%0A%231D130D%0A%23AE7542%0A%23120800%0A%23FCECE2%0A%23F9DDCF%0A";
ColorPallet[28] = "%23FFC3C3%0A%23FFE2C3%0A%23FDFFC3%0A%23DEFFC3%0A%23C3FFC7%0A%23C3FFE6%0A%23C3F9FF%0A%23C3DAFF%0A%23CBC3FF%0A%23EBC3FF%0A%23FFC3F4%0A%23FFC3D5%0A%23FCECE2%0A%23F9DDCF%0A";
ColorPallet[29] = "%23000000%0A%23FFFFFF%0A%23B47575%0A%23888888%0A%23FA9696%0A%23C096C0%0A%23FFB6FF%0A%238080FF%0A%2325C7C9%0A%23E7E58D%0A%23E7962D%0A%2399CB7B%0A%23FCECE2%0A%23F9DDCF%0A";

function setPalletToApplet(cp) {
    var applet = document.paintbbs;
    if (!applet) {
        alert("Avbgǂݍ܂Ă܂");
        return;
    }
    if ( cp < 1 || cp > ColorPallet.length ) {
        alert("͈͊ÕpbgIĂ܂");
        return;
    }
    applet.setColors(unescape(ColorPallet[cp]));
}

function confirmSubmit() {
    var applet = document.paintbbs;
    if (!applet) {
        alert("Avbgǂݍ܂Ă܂");
        return;
    }
    jQuery("//input[@name='post']").attr({
        "value": ( jQuery("input#temporarySave").get(0).checked ? 0 : 1 ) });
    document.paintbbs.str_header = jQuery.param(jQuery("form#notePostForm").fastSerialize());
    applet.pExit();
}

function paintBBSCallback(callbackValue) {
    if (callbackValue == "header") {
        var option = { "expires": 30, "path": "<?cs var:html_escape(BBS_COOKIE_PATH) ?>" };
        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
        return jQuery.param(jQuery("form#notePostForm").fastSerialize());
    }
}

//-->
</script>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">

<tr><td>
<?cs if:UsePaintBBS ?><applet code="pbbs.PaintBBS.class"
  archive="<?cs var:html_escape(StaticURI) ?>/applet/PaintBBS.jar"
  name="paintbbs" width="<?cs var:html_escape(CanvasWidth) ?>" height="<?cs var:html_escape(CanvasHeight) ?>"
  align="center" mayscript="mayscript"><?cs /if ?>
<?cs if:UseShiiPainter ?><applet code="c.ShiPainter.class" name="paintbbs"
  archive="<?cs var:html_escape(StaticURI) ?>/applet/spainter_all.jar"
  width="<?cs var:html_escape(CanvasWidth) ?>" height="<?cs var:html_escape(CanvasHeight) ?>" mayscript="mayscript">
  <param name="tt.zip" value="tt.zip">
  <param name="res.zip" value="res_normal.zip">
  <param name="tools" value="normal"><?cs /if ?>
<?cs if:UseShiiPainterPro ?><applet code="c.ShiPainter.class" name="paintbbs"
  archive="<?cs var:html_escape(StaticURI) ?>/applet/spainter_all.jar"
  width="<?cs var:html_escape(CanvasWidth) ?>" height="<?cs var:html_escape(CanvasHeight) ?>" mayscript="mayscript">
  <param name="tt.zip" value="tt.zip">
  <param name="res.zip" value="res_pro.zip">
  <param name="tools" value="pro"><?cs /if ?>
  <param name="image_width" value="<?cs var:html_escape(ImageWidth) ?>">
  <param name="image_height" value="<?cs var:html_escape(ImageHeight) ?>">
  <param name="image_bkcolor" value="#ffffff">
  <param name="compress_level" value="15">
  <param name="undo" value="90">
  <param name="undo_in_mg" value="15">
  <param name="url_save" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi">
  <param name="url_exit" value="<?cs var:html_escape(BBSURI) ?>/">
  <param name="send_advance" value="true">
  <param name="send_header" value="<?cs if:KEY ?>bbs=<?cs var:html_escape(BBS) ?>&key=<?cs var:html_escape(KEY) ?>&resno=<?cs var:html_escape(ResNumber) ?>&editpass=<?cs var:html_escape(EditPass) ?>&action=update<?cs else ?>bbs=<?cs var:html_escape(BBS) ?>&post=0&action=save<?cs /if ?>">
  <param name="send_header_count" value="true">
  <param name="send_header_image_type" value="true">
  <param name="send_header_timer" value="true">
  <param name="send_language" value="sjis">
  <param name="poo" value="false">
  <param name="security_click" value="0">
  <param name="security_timer" value="0">
  <param name="security_url" value="http://www.npa.go.jp/">
  <param name="security_post" value="false">
  <param name="scriptable" value="true">
  <param name="MAYSCRIPT" value="true">
<?cs if:ResNumber ?>
  <param name="image_canvas" value="<?cs var:html_escape(BBSURI) ?>/img/<?cs var:html_escape(KEY) ?>/<?cs var:html_escape(ResNumber) ?>.<?cs var:html_escape(Extension) ?>">
  <param name="pch_file" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=pch&bbs=<?cs var:html_escape(BBS) ?>&key=<?cs var:html_escape(KEY) ?>&resno=<?cs var:html_escape(ResNumber) ?>"><?cs /if ?>
<?cs if:DraftId ?>
  <param name="image_canvas" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=load&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(DraftId) ?>">
  <param name="pch_file" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=pch&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(DraftId) ?>"><?cs /if ?>
<?cs if:EnableJPEG ?>
  <param name="image_jpeg" value="true">
  <param name="image_size" value="1"><?cs else ?>
  <param name="image_jpeg" value="true">
  <param name="image_size" value="60"><?cs /if ?>
<?cs if:EnableAnimation ?>
  <param name="thumbnail_type" value="animation">
  <param name="thumbnail_width" value="100%">
  <param name="thumbnail_height" value="100%"><?cs /if ?>
</applet>
</td><td>
<div align="left">
<form action="#" method="post">
<label for="pallet1" size="2" style="font-weight:bold;color:#FF0000"></span>
<input id="pallet1" onclick="setPalletToApplet(1)" type="radio" name="pallet">
<label for="pallet2" size="2" style="font-weight:bold;color:#FF3F00"></span>
<input id="pallet2" onclick="setPalletToApplet(2)" type="radio" name="pallet"><br>
<label for="pallet3" size="2" style="font-weight:bold;color:#FF7F00"></span>
<input id="pallet3" onclick="setPalletToApplet(3)" type="radio" name="pallet">
<label for="pallet4" size="2" style="font-weight:bold;color:#FFBF00"></span>
<input id="pallet4" onclick="setPalletToApplet(4)" type="radio" name="pallet"><br>
<label for="pallet5" size="2" style="font-weight:bold;color:#FFFF00"></span>
<input id="pallet5" onclick="setPalletToApplet(5)" type="radio" name="pallet">
<label for="pallet6" size="2" style="font-weight:bold;color:#BFFF00"></span>
<input id="pallet6" onclick="setPalletToApplet(6)" type="radio" name="pallet"><br>
<label for="pallet7" size="2" style="font-weight:bold;color:#7FFF00"></span>
<input id="pallet7" onclick="setPalletToApplet(7)" type="radio" name="pallet">
<label for="pallet8" size="2" style="font-weight:bold;color:#3FFF00"></span>
<input id="pallet8" onclick="setPalletToApplet(8)" type="radio" name="pallet"><br>
<label for="pallet9" size="2" style="font-weight:bold;color:#00FF00"></span>
<input id="pallet9" onclick="setPalletToApplet(9)" type="radio" name="pallet">
<label for="pallet10" size="2" style="font-weight:bold;color:#00FF3F"></span>
<input id="pallet10" onclick="setPalletToApplet(10)" type="radio" name="pallet"><br>
<label for="pallet11" size="2" style="font-weight:bold;color:#00FF7F"></span>
<input id="pallet11" onclick="setPalletToApplet(11)" type="radio" name="pallet">
<label for="pallet12" size="2" style="font-weight:bold;color:#00FFBF"></span>
<input id="pallet12" onclick="setPalletToApplet(12)" type="radio" name="pallet"><br>
<label for="pallet13" size="2" style="font-weight:bold;color:#00FFFF"></span>
<input id="pallet13" onclick="setPalletToApplet(13)" type="radio" name="pallet">
<label for="pallet14" size="2" style="font-weight:bold;color:#00BFFF"></span>
<input id="pallet14" onclick="setPalletToApplet(14)" type="radio" name="pallet"><br>
<label for="pallet15" size="2" style="font-weight:bold;color:#007FFF"></span>
<input id="pallet15" onclick="setPalletToApplet(15)" type="radio" name="pallet">
<label for="pallet16" size="2" style="font-weight:bold;color:#003FFF"></span>
<input id="pallet16" onclick="setPalletToApplet(16)" type="radio" name="pallet"><br>
<label for="pallet17" size="2" style="font-weight:bold;color:#0000FF"></span>
<input id="pallet17" onclick="setPalletToApplet(17)" type="radio" name="pallet">
<label for="pallet18" size="2" style="font-weight:bold;color:#3F00FF"></span>
<input id="pallet18" onclick="setPalletToApplet(18)" type="radio" name="pallet"><br>
<label for="pallet19" size="2" style="font-weight:bold;color:#7F00FF"></span>
<input id="pallet19" onclick="setPalletToApplet(19)" type="radio" name="pallet">
<label for="pallet20" size="2" style="font-weight:bold;color:#BF00FF"></span>
<input id="pallet20" onclick="setPalletToApplet(20)" type="radio" name="pallet"><br>
<label for="pallet21" size="2" style="font-weight:bold;color:#FF00FF"></span>
<input id="pallet21" onclick="setPalletToApplet(21)" type="radio" name="pallet">
<label for="pallet22" size="2" style="font-weight:bold;color:#FF00BF"></span>
<input id="pallet22" onclick="setPalletToApplet(22)" type="radio" name="pallet"><br>
<label for="pallet23" size="2" style="font-weight:bold;color:#FF007F"></span>
<input id="pallet23" onclick="setPalletToApplet(23)" type="radio" name="pallet">
<label for="pallet24" size="2" style="font-weight:bold;color:#FF003F"></span>
<input id="pallet24" onclick="setPalletToApplet(24)" type="radio" name="pallet"><br>
<input id="pallet25" onclick="setPalletToApplet(25)" type="radio" name="pallet">
<label for="pallet25" size="2" style="color:#00000">mN</span><br>
<input id="pallet26" onclick="setPalletToApplet(26)" type="radio" name="pallet">
<label for="pallet26" size="2" style="color:#000000">F</span><br>
<input id="pallet27" onclick="setPalletToApplet(27)" type="radio" name="pallet">
<label for="pallet27" size="2" style="color:#000000">ZsA</span><br>
<input id="pallet28" onclick="setPalletToApplet(28)" type="radio" name="pallet">
<label for="pallet28" size="2" style="color:#000000">pXe</span><br>
<input id="pallet29" onclick="setPalletToApplet(29)" type="radio" name="pallet">
<label for="pallet29" size="2" style="color:#000000">ftHg</span><br>
</form>
</div>
</td></tr>

<?cs if:!KEY ?>
<tr><td colspan="2">
<noscript>
<span style="color:red"><strong>
esɂJavaScriptLɂKv܂B
</strong></span>
</noscript>
<form class="comment" id="notePostForm" method="POST"
  action="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi"
  onsubmit="confirmSubmit(); return false">
<input type="submit" value="e" name="submit">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
<input type="hidden" name="post" value="0">
<input type="hidden" name="action" value="save">
<input type="checkbox" name="temporary" value="1" id="temporarySave">
<label for="temporarySave">ړe摜̈ꎞۑs</label><br>
eXbhF<select name="key">
<?cs each:item = Threads ?>
<option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?>(<?cs var:html_escape(item.res) ?>)</option>
<?cs /each ?>
</select><br>
OF<input type="text" name="FROM" size="19">
E-mailF<input type="text" name="mail" size="19"><br>
<textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
ҏWpXF<input type="password" name="editpass"><br>
<?cs if:Uploadable ?>폜pXF<input type="password" name="pass"><?cs /if ?>
</form>
</td>
</tr>
<?cs /if ?>

<?cs if:Banner ?><tr><td><?cs var:Banner ?></td></tr><?cs /if ?>

</table>

</body>
</html>
